@@ -1,5 +1,6 @@
 from django.conf import settings
 
+LOGIN_URL = getattr(settings, 'LOGIN_URL', None)
 MEDIA_URL = getattr(settings, 'MEDIA_URL', None)
 DEBUG = getattr(settings, 'DEBUG', False)
 SITE_ID = getattr(settings, 'SITE_ID', 1)
@@ -19,7 +20,8 @@ BLOG_PING_SERVERS = getattr(settings, 'BLOG_PING_SERVERS', (
 BLOG_FEED_ITEMS = getattr(settings, 'BLOG_FEED_ITEMS', 20)
 
 # lithium.wiki
-WIKI_DEFAULT_USER_PERMISSION = getattr(settings, 'WIKI_DEFAULT_USER_PERMISSION', 1)
+WIKI_DEFAULT_READ_PERMISSION = getattr(settings, 'WIKI_DEFAULT_READ_PERMISSION', 1)
+WIKI_DEFAULT_WRITE_PERMISSION = getattr(settings, 'WIKI_DEFAULT_WRITE_PERMISSION', 1)
 WIKI_HISTORY_PAGINATE_BY = getattr(settings, 'WIKI_HISTORY_PAGINATE_BY', 50)
 
 # lithium.forum
